T0327 station located at Monte Bondone-Viotte (Trentino, Easter Alps, Italy) from August 2004 to December 2012.\The zoo object 'meteo' contains:
[object Object],[object Object],[object Object],[object Object],[object Object],[object Object]
The corresponding time axis vector for each observation can be printed by typing index(meteo).
data(bondone)This dataset is intended for research purposes only, being distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY.